@@ -52,6 +52,7 @@ struct _SearchFilesPrivate
 
 	GtkWidget* files_tree;
 	GtkTreeModel* files_model;
+	GtkWidget* scrolled_window;
 
 	GtkWidget* files_tree_check;
 
@@ -96,6 +97,8 @@ G_DEFINE_TYPE (SearchFiles, search_files, G_TYPE_OBJECT);
 G_MODULE_EXPORT void search_files_search_clicked (SearchFiles* sf);
 G_MODULE_EXPORT void search_files_replace_clicked (SearchFiles* sf);
 G_MODULE_EXPORT void search_files_update_ui (SearchFiles* sf);
+G_MODULE_EXPORT gboolean search_files_key_pressed (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
+
 
 void
 search_files_update_ui (SearchFiles* sf)
@@ -168,8 +171,20 @@ search_files_check_column_toggled (GtkCellRendererToggle* renderer,
 static void
 search_files_finished (SearchFiles* sf, AnjutaCommandQueue* queue)
 {
+	GtkAdjustment* h_adj;
+	GtkAdjustment* v_adj;
+
 	g_object_unref (queue);
 	sf->priv->busy = FALSE;
+
+	/* Scroll to first item */
+	h_adj = 
+		gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (sf->priv->scrolled_window));
+	v_adj = 
+		gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sf->priv->scrolled_window));
+	gtk_adjustment_set_value (h_adj, 0.0);
+	gtk_adjustment_set_value (v_adj, 0.0);
+
 	search_files_update_ui(sf);
 }
 
@@ -456,10 +471,15 @@ search_files_search_clicked (SearchFiles* sf)
 		g_signal_connect (queue, "finished",
 	    	              G_CALLBACK (search_files_filter_finished), sf);
 		for (file = files; file != NULL; file = g_list_next (file))
-		{
+		{	
 			SearchFilterFileCommand* cmd =
 				search_filter_file_command_new(G_FILE (file->data),
 			    	                           mime_types);
+
+			/* Check we are searching in project files only */
+			if (!g_file_has_prefix (G_FILE (file->data), sf->priv->project_file))
+				continue;
+			
 			g_signal_connect (cmd, "command-finished",
 		    	              G_CALLBACK (search_files_filter_command_finished), sf);
 			anjuta_command_queue_push(queue, ANJUTA_COMMAND(cmd));
@@ -790,6 +810,8 @@ search_files_init (SearchFiles* sf)
 
 	sf->priv->files_tree = GTK_WIDGET (gtk_builder_get_object(sf->priv->builder,
 	                                                          "files_tree"));
+	sf->priv->scrolled_window = GTK_WIDGET (gtk_builder_get_object (sf->priv->builder,
+	                                                                "scrolled_window"));
 
 	search_files_init_tree(sf);
 
@@ -862,6 +884,38 @@ search_files_new (AnjutaDocman* docman, SearchBox* search_box)
 	return sf;
 }
 
+gboolean
+search_files_key_pressed (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+{
+	SearchFiles* sf = SEARCH_FILES(user_data);
+	IAnjutaDocument* doc;
+	
+	g_return_val_if_fail (widget != NULL, FALSE);
+	g_return_val_if_fail (event != NULL, FALSE);
+	g_return_val_if_fail (sf != NULL, FALSE);
+
+	switch (event->keyval)
+	{
+		case GDK_KEY_Escape:
+		{
+			anjuta_shell_hide_dockable_widget (sf->priv->docman->shell,
+			                                   sf->priv->main_box,
+			                                   NULL);
+			/* Check if document is open */
+			doc = anjuta_docman_get_current_document(sf->priv->docman);
+
+			if (doc)
+			{
+				anjuta_docman_present_notebook_page(sf->priv->docman,
+				                                    doc);
+			}
+			return TRUE;
+		}
+		default:
+			return FALSE;
+	}
+}
+
 void search_files_present (SearchFiles* sf)
 {
 	g_return_if_fail (sf != NULL && SEARCH_IS_FILES(sf));
@@ -874,4 +928,6 @@ void search_files_present (SearchFiles* sf)
 	anjuta_shell_present_widget(sf->priv->docman->shell,
 	                            sf->priv->main_box,
 	                            NULL);
+
+	gtk_widget_grab_focus (sf->priv->search_entry);
 }
