@@ -1053,6 +1053,8 @@ gbf_project_view_update_tree (GbfProjectView *view, AnjutaProjectNode *parent, G
 		gbf_project_model_add_node (view->model, node->data, iter, 0);
 	}
 
+	g_list_free (nodes);
+
 	/* Expand parent, needed if the parent hasn't any children when it was created */
 	if (iter != NULL)
 	{
@@ -1422,21 +1424,17 @@ on_node_loaded (AnjutaPmProject *sender, AnjutaProjectNode *node, gboolean compl
 				else
 				{
 					GbfTreeData *data;
+					GbfTreeData *new_data;
 
+					/* Replace with new node */
 					gtk_tree_model_get (GTK_TREE_MODEL (view->model), &iter,
 						GBF_PROJECT_MODEL_COLUMN_DATA, &data,
 						-1);
-					if (data->type == GBF_TREE_NODE_UNKNOWN)
-					{
-						/* Replace with real node */
-						GbfTreeData *new_data;
-
-						new_data = gbf_tree_data_new_node (node);
-						gtk_tree_store_set (GTK_TREE_STORE (view->model), &iter,
-									GBF_PROJECT_MODEL_COLUMN_DATA, new_data,
-									-1);
-						gbf_tree_data_free (data);
-					}
+					new_data = gbf_tree_data_new_node (node);
+					gtk_tree_store_set (GTK_TREE_STORE (view->model), &iter,
+								GBF_PROJECT_MODEL_COLUMN_DATA, new_data,
+								-1);
+					gbf_tree_data_free (data);
 					gbf_project_view_update_tree (view, node, &iter);
 				}
 
