@@ -112,8 +112,22 @@ typedef struct
 	gint handle;
 	gint line;
 	const gchar* category;
+	gchar* tooltip;
 } MarkerReload;
 
+static MarkerReload*
+marker_reload_new (void)
+{
+	return g_slice_new0 (MarkerReload);
+}
+
+static void
+marker_reload_free (MarkerReload* mark)
+{
+	g_free (mark->tooltip);
+	g_slice_free (MarkerReload, mark);
+}
+
 /* HIGHLIGHTED TAGS */
 
 #define IMPORTANT_INDIC "important_indic"
@@ -468,7 +482,7 @@ sourceview_reload_save_markers (Sourceview* sv)
 
 	do
 	{
-		MarkerReload* reload = g_new0(MarkerReload, 1);
+		MarkerReload* reload = marker_reload_new ();
 
 		gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (sv->priv->document),
 		                                  iter, GTK_TEXT_MARK (source_mark));
@@ -477,6 +491,9 @@ sourceview_reload_save_markers (Sourceview* sv)
 
 		sscanf (gtk_text_mark_get_name (GTK_TEXT_MARK (source_mark)),
 		        MARK_NAME "%d", &reload->handle);
+		sv->priv->tooltip = g_strdup (g_object_get_data (G_OBJECT (source_mark),
+														 MARKER_TOOLTIP_DATA));
+			
 		sv->priv->reload_marks = g_slist_append (sv->priv->reload_marks, reload);
 	}
 	while ((source_mark = gtk_source_mark_next (source_mark, NULL)));
@@ -485,6 +502,26 @@ sourceview_reload_save_markers (Sourceview* sv)
 	gtk_text_iter_free (iter);
 }
 
+static void
+sourceview_add_mark (Sourceview* sv, gint handle, gint line,
+                     const gchar* category, const gchar* tooltip)
+{
+	GtkTextIter iter;
+	gchar* name;
+	GtkSourceMark* source_mark;
+
+	gtk_text_buffer_get_iter_at_line(GTK_TEXT_BUFFER(sv->priv->document),
+									 &iter, line);
+
+	name = CREATE_MARK_NAME (handle);
+	source_mark = gtk_source_buffer_create_source_mark(GTK_SOURCE_BUFFER(sv->priv->document),
+													   name, category, &iter);
+
+	g_object_set_data_full (G_OBJECT (source_mark), MARKER_TOOLTIP_DATA,
+							g_strdup (tooltip), (GDestroyNotify)g_free);
+	g_free (name);
+}
+
 static void
 sourceview_reload_restore_markers (Sourceview* sv)
 {
@@ -493,16 +530,11 @@ sourceview_reload_restore_markers (Sourceview* sv)
 	     cur_mark = g_slist_next (cur_mark))
 	{
 		MarkerReload* mark = cur_mark->data;
-		GtkTextIter iter;
-		gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (sv->priv->document),
-		                                  &iter,
-		                                  mark->line);
-		gtk_source_buffer_create_source_mark (GTK_SOURCE_BUFFER (sv->priv->document),
-		                                      CREATE_MARK_NAME (mark->handle),
-		                                      mark->category, &iter);
+
+		sourceview_add_mark (sv, mark->handle, mark->line, mark->category,
+							 mark->tooltip);
 	}
-	g_slist_foreach (sv->priv->reload_marks, (GFunc)g_free, NULL);
-	g_slist_free (sv->priv->reload_marks);
+	g_slist_free_full (sv->priv->reload_marks, (GDestroyNotify)marker_reload_free);
 	sv->priv->reload_marks = NULL;
 }
 
@@ -514,11 +546,6 @@ on_reload_dialog_response (GtkWidget *message_area, gint res, Sourceview *sv)
 	{
 		GFile* file = sourceview_io_get_file (sv->priv->io);
 
-		/* Save marks and position */
-		sv->priv->goto_line =
-			LOCATION_TO_LINE(ianjuta_editor_get_lineno (IANJUTA_EDITOR(sv), NULL));
-		sourceview_reload_save_markers (sv);
-
 		ianjuta_file_open(IANJUTA_FILE(sv),
 						  file, NULL);
 		g_object_unref (file);
@@ -871,15 +898,12 @@ static void
 sourceview_dispose(GObject *object)
 {
 	Sourceview *cobj = ANJUTA_SOURCEVIEW(object);
-	GSList* node;
 
-	for (node = cobj->priv->idle_sources; node != NULL; node = g_slist_next (node))
+	if (cobj->priv->reload_marks)
 	{
-		g_source_remove (GPOINTER_TO_UINT (node->data));
+		g_slist_free_full (cobj->priv->reload_marks, (GDestroyNotify)marker_reload_free);
+		g_slist_free (cobj->priv->reload_marks);
 	}
-	g_slist_free (cobj->priv->idle_sources);
-	cobj->priv->idle_sources = NULL;	
-
 	if (cobj->priv->assist_tip)
 	{
 		gtk_widget_destroy(GTK_WIDGET(cobj->priv->assist_tip));
@@ -887,13 +911,18 @@ sourceview_dispose(GObject *object)
 	}
 	if (cobj->priv->io)
 	{
+		g_signal_handlers_disconnect_by_func (cobj->priv->io, on_file_changed, cobj);
+		g_signal_handlers_disconnect_by_func (cobj->priv->io, on_file_deleted, cobj);
+		g_signal_handlers_disconnect_by_func (cobj->priv->io, on_open_finish, cobj);
+		g_signal_handlers_disconnect_by_func (cobj->priv->io, on_open_failed, cobj);
+		g_signal_handlers_disconnect_by_func (cobj->priv->io, on_save_finish, cobj);
+		g_signal_handlers_disconnect_by_func (cobj->priv->io, on_save_failed, cobj);
+		
+		sourceview_io_cancel (cobj->priv->io);
 		g_clear_object (&cobj->priv->io);
 	}
 
-	if (cobj->priv->tooltip_cell)
-	{
-		g_clear_object (&cobj->priv->tooltip_cell);
-	}
+	g_clear_object (&cobj->priv->tooltip_cell);
 
 	sourceview_prefs_destroy(cobj);
 	
@@ -949,6 +978,18 @@ static void
 ifile_open (IAnjutaFile* ifile, GFile* file, GError** e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(ifile);
+
+	GFile *previous_file;
+
+	previous_file = sourceview_io_get_file (sv->priv->io);
+	if (previous_file && g_file_equal (file, previous_file))
+	{
+		/* This is a reload so save marks and position */
+		sv->priv->goto_line =
+			LOCATION_TO_LINE(ianjuta_editor_get_lineno (IANJUTA_EDITOR(sv), NULL));
+		sourceview_reload_save_markers (sv);
+	}
+
 	/* Hold a reference here to avoid a destroyed editor */
 	g_object_ref(G_OBJECT(sv));
 	gtk_text_buffer_set_text (GTK_TEXT_BUFFER(sv->priv->document),
@@ -1052,7 +1093,6 @@ ieditor_set_tab_size (IAnjutaEditor *editor, gint tabsize, GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
 	gtk_source_view_set_tab_width(GTK_SOURCE_VIEW(sv->priv->view), tabsize);
-	gtk_source_view_set_indent_width (GTK_SOURCE_VIEW (sv->priv->view), tabsize);
 }
 
 static gboolean
@@ -1078,6 +1118,19 @@ ieditor_set_auto_indent (IAnjutaEditor *editor, gboolean auto_indent, GError **e
 									auto_indent);
 }
 
+static gint
+ieditor_get_indent_size (IAnjutaEditor *editor, GError **e)
+{
+	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
+	return gtk_source_view_get_indent_width (GTK_SOURCE_VIEW (sv->priv->view));
+}
+
+static void
+ieditor_set_indent_size (IAnjutaEditor *editor, gint indentsize, GError **e)
+{
+	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
+	gtk_source_view_set_indent_width (GTK_SOURCE_VIEW (sv->priv->view), indentsize);
+}
 
 /* Scroll to line */
 static void ieditor_goto_line(IAnjutaEditor *editor, gint line, GError **e)
@@ -1418,7 +1471,9 @@ ieditor_iface_init (IAnjutaEditorIface *iface)
 	iface->set_tabsize = ieditor_set_tab_size;
 	iface->get_use_spaces = ieditor_get_use_spaces;
 	iface->set_use_spaces = ieditor_set_use_spaces;
-    iface->set_auto_indent = ieditor_set_auto_indent;
+	iface->set_auto_indent = ieditor_set_auto_indent;
+	iface->get_indentsize = ieditor_get_indent_size;
+	iface->set_indentsize = ieditor_set_indent_size;
 	iface->goto_line = ieditor_goto_line;
 	iface->goto_position = ieditor_goto_position;
 	iface->get_text = ieditor_get_text;
@@ -1830,60 +1885,11 @@ iconvert_iface_init(IAnjutaEditorConvertIface* iface)
 	iface->to_lower = iconvert_to_lower;
 }
 
-typedef struct
-{
-	IAnjutaMarkableMarker marker;
-	gint location;
-	gint handle;
-	guint source;
-	gchar* tooltip;
-	Sourceview* sv;
-} SVMark;
-
-static gboolean mark_real (gpointer data)
-{
-	SVMark* svmark = data;
-	Sourceview* sv = svmark->sv;
-	GtkTextIter iter;
-	GtkSourceMark* source_mark;
-	const gchar* category;
-	gint location = svmark->location;
-	gint marker_count = svmark->handle;
-	gchar* tooltip = svmark->tooltip;
-	IAnjutaMarkableMarker marker = svmark->marker;
-	gchar* name;
-
-	if (sv->priv->loading)
-	{
-		/* Wait until loading is finished */
-		return TRUE;
-	}
-
-	gtk_text_buffer_get_iter_at_line(GTK_TEXT_BUFFER(sv->priv->document),
-									 &iter, LOCATION_TO_LINE (location));
-
-	category = marker_types[marker];
-	name = CREATE_MARK_NAME (marker_count);
-
-
-	source_mark = gtk_source_buffer_create_source_mark(GTK_SOURCE_BUFFER(sv->priv->document),
-												name, category, &iter);
-	g_object_set_data_full (G_OBJECT (source_mark), MARKER_TOOLTIP_DATA, tooltip,
-	                        (GDestroyNotify) g_free);
-
-	g_source_remove (svmark->source);
-
-	g_free (name);
-	g_slice_free (SVMark, svmark);
-	return FALSE;
-}
-
 static gint
 imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
            const gchar* tooltip, GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(mark);
-	SVMark* svmark = g_slice_new0 (SVMark);
 
 	if (location <= 0)
 	{
@@ -1896,15 +1902,20 @@ imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 
 	marker_count++;
 
-	svmark->sv = sv;
-	svmark->location = location;
-	svmark->handle = marker_count;
-	svmark->marker = marker;
-	svmark->tooltip = tooltip ? g_strdup (tooltip) : NULL;
-	svmark->source = g_idle_add (mark_real, svmark);
+	if (sv->priv->loading)
+	{
+		MarkerReload* mark = marker_reload_new ();
 
-	sv->priv->idle_sources = g_slist_prepend (sv->priv->idle_sources,
-											  GUINT_TO_POINTER (svmark->source));
+		mark->handle = marker_count;
+		mark->line = LOCATION_TO_LINE(location);
+		mark->category = marker_types[marker];
+		mark->tooltip = g_strdup (tooltip);
+
+		sv->priv->reload_marks = g_slist_prepend (sv->priv->reload_marks, mark);
+	}
+	else
+		sourceview_add_mark (sv, marker_count, LOCATION_TO_LINE(location), marker_types[marker],
+							 tooltip);
 
 	return marker_count;
 }
@@ -2371,6 +2382,7 @@ iassist_proposals(IAnjutaEditorAssist* iassist,
 			}
 			gtk_source_completion_context_add_proposals (prov->context, GTK_SOURCE_COMPLETION_PROVIDER(prov),
 			                                             items, finished);
+			g_list_free_full (items, g_object_unref);
 			break;
 		}
 	}
