@@ -546,8 +546,22 @@ anjuta_window_dispose (GObject *widget)
 		g_hash_table_destroy (win->values);
 		win->values = NULL;
 	}
-
+	if (win->ui) {
+		g_object_unref (win->ui);
+		win->ui = NULL;
+	}
+	if (win->preferences)
+	{
+		g_object_unref (win->preferences);
+		win->preferences = NULL;
+	}
 	if (win->layout_manager) {
+		/* Disconnect signal handlers so we don't get any signals after we're
+		 * disposed. */
+		g_signal_handlers_disconnect_by_func (win->layout_manager, on_layout_dirty_notify,
+		                                      win);
+		g_signal_handlers_disconnect_by_func (gdl_dock_layout_get_master (win->layout_manager),
+		                                      on_layout_locked_notify, win);
 		g_object_unref (win->layout_manager);
 		win->layout_manager = NULL;
 	}
@@ -572,21 +586,6 @@ anjuta_window_dispose (GObject *widget)
 	G_OBJECT_CLASS (parent_class)->dispose (widget);
 }
 
-static void
-anjuta_window_finalize (GObject *widget)
-{
-	AnjutaWindow *win;
-
-	g_return_if_fail (ANJUTA_IS_WINDOW (widget));
-
-	win = ANJUTA_WINDOW (widget);
-
-	gtk_widget_destroy (GTK_WIDGET (win->ui));
-	gtk_widget_destroy (GTK_WIDGET (win->preferences));
-
-	G_OBJECT_CLASS (parent_class)->finalize (widget);
-}
-
 static void
 anjuta_window_instance_init (AnjutaWindow *win)
 {
@@ -826,7 +825,6 @@ anjuta_window_class_init (AnjutaWindowClass *class)
 	object_class = (GObjectClass*) class;
 	widget_class = (GtkWidgetClass*) class;
 
-	object_class->finalize = anjuta_window_finalize;
 	object_class->dispose = anjuta_window_dispose;
 
 	widget_class->key_press_event = anjuta_window_key_press_event;
